% basis_and_nn_decomp - clustering of data matrix X through clustering of EKM of X (FIX)
%                        into nonoverlapping binary (0,1)factors.
%                       w.r.t. to clustering of the EKM of basis V (FIV)
%           

% INPUTS:
%   FIX       - DxT EKM of data matrix X
%   FIV       - DXD EKM of basis matrix V selected by FVS algorithm
%   M       - number of "sources"/clusters

%OUTPUT:
% 
%   S       - MxT matrix of binary factors (cluster assignments)

%
% COPYRIGHT: I. Kopriva, ZLAIR, IRB, Zagreb, Croatia
% DATE:      2015/11/13; 

function [idx] = basis_and_nn_decomp(FIX,FIV,M)

% estimate mixing matrix in RKHS
 AH = zeros(size(FIV,1),M);
 TC = clusterdata(FIV','distance','cosine','linkage','complete','maxclus',M);
 for i=1:length(TC)
        ind = TC(i);
        AH(:,ind)=AH(:,ind)+FIV(:,i);
 end

 AH(:,TC(1:M))=FIV(:,1:M);
  
 %AH = FIV;
 
% normalize column-wise to unit L2-norm
AH = bsxfun(@rdivide,AH,sqrt(sum(AH.*AH,1)));

idx=knnsearch(AH',FIX');



 